@@ -34,3 +34,26 @@ test_that("different outs work", {
     expect_is(ReadNetCDF(file, out = "array")[[1]], "array")
     expect_is(ReadNetCDF(file, out = "vector")[[1]], "numeric")
 })
+
+
+test_that("time dimension without 'since' works", {
+    file <- "weird_datesmall.nc"
+    read <- ReadNetCDF(file)
+    expect_known_output(ReadNetCDF(file), "readnetcdf_time_hours")
+})
+
+
+test_that("can read from nc_open", {
+    nc <- ncdf4::nc_open(file)
+    expect_known_value(ReadNetCDF(nc), "readnetcdf_nc_open")
+    expect_known_value(ReadNetCDF(nc), "readnetcdf_nc_open2")
+})
+
+
+test_that("can read from urls", {
+    url <- "http://iridl.ldeo.columbia.edu/SOURCES/.Models/.SubX/.GMAO/.GEOS_V2p1/.hindcast/.ua/dods"
+    skip_if_offline()
+    skip_on_cran()
+    expect_class(GlanceNetCDF(url), "nc_glance")
+})
+
